@@ -23,7 +23,7 @@ from ui.systray import QApp_SysTrayIndicator
 from QSingleApplication import QSingleApplicationTCP
 
 APP_NAME = "ThinkFan UI"
-APP_VERSION = "1.0.0"
+APP_VERSION = "1.0.2"
 APP_DESKTOP_NAME = "thinkfan-ui"
 APP_UUID = "587dedfb-19f2-4b2a-bc74-3d656e80966a"
 
@@ -288,14 +288,11 @@ class MainWindow(QMainWindow, Ui_MainWindow):
     # --- MODIFIED: New fan mode handlers ---
     def _set_fan_mode_auto(self):
         self.app.setFanSpeed("auto")
-        self.slider.setEnabled(False)
 
     def _set_fan_mode_full(self):
         self.app.setFanSpeed("full-speed")
-        self.slider.setEnabled(False)
 
     def _set_fan_mode_manual(self):
-        self.slider.setEnabled(True)
         self.app.setFanSpeed(self.slider.value())
 
     def _slider_value_changed(self, value):
